@@ -2,15 +2,15 @@
 
 package Validation::Class::Prototype;
 {
-  $Validation::Class::Prototype::VERSION = '7.00_01';
+  $Validation::Class::Prototype::VERSION = '7.00_02';
 }
 
 use strict;
 use warnings;
 
-our $VERSION = '7.00_01'; # VERSION
+our $VERSION = '7.00_02'; # VERSION
 
-use base 'Validation::Class::Backwards'; # we're pro-life
+use base 'Validation::Class::Backwards'; # I'm pro-life
 
 use Carp 'confess';
 use Hash::Merge 'merge';
@@ -324,7 +324,7 @@ sub apply_validator {
         my $error = defined $field->{error} ?
             $field->{error} : "$name is required";
         
-        $field->{errors}->add_error($error);
+        $field->{errors}->add($error);
         
         return $self; # if required and fails, stop processing immediately
     
@@ -935,7 +935,7 @@ sub configuration_validator_between {
             my $handle = $field->{label} || $field->{name};
             my $error  = "$handle must contain between $directive characters";
             
-            $field->errors->add_error($field->{error} || $error);
+            $field->errors->add($field->{error} || $error);
             
             return 0;
     
@@ -976,7 +976,7 @@ sub configuration_validator_depends_on {
                 my $error = "$handle requires " . join(", ", @blanks) .
                     " to have " . (@blanks > 1 ? "values" : "a value");
                 
-                $field->errors->add_error($field->{error} || $error);
+                $field->errors->add($field->{error} || $error);
 
                 return 0;
 
@@ -1007,7 +1007,7 @@ sub configuration_validator_length {
             my $error = "$handle must contain exactly " .
                 "$directive $characters";
             
-            $field->errors->add_error($field->{error} || $error);
+            $field->errors->add($field->{error} || $error);
 
             return 0;
 
@@ -1037,7 +1037,7 @@ sub configuration_validator_matches {
             
             my $error = "$handle does not match $handle2";
             
-            $field->errors->add_error($field->{error} || $error);
+            $field->errors->add($field->{error} || $error);
             
             return 0;
             
@@ -1066,7 +1066,7 @@ sub configuration_validator_max_alpha {
             my $error = "$handle must contain at-least "
                 . "$directive alphabetic $characters";
             
-            $field->errors->add_error($field->{error} || $error);
+            $field->errors->add($field->{error} || $error);
             
             return 0;
         
@@ -1095,7 +1095,7 @@ sub configuration_validator_max_digits {
             my $error = "$handle must contain at-least "
                 ."$directive $characters";
             
-            $field->errors->add_error($field->{error} || $error);
+            $field->errors->add($field->{error} || $error);
             
             return 0;
 
@@ -1122,7 +1122,7 @@ sub configuration_validator_max_length {
             my $error = "$handle can't contain more than "
                 ."$directive $characters";
             
-            $field->errors->add_error($field->{error} || $error);
+            $field->errors->add($field->{error} || $error);
 
             return 0;
 
@@ -1146,7 +1146,7 @@ sub configuration_validator_max_sum {
             my $error = "$handle can't be greater than "
                 ."$directive";
             
-            $field->errors->add_error($field->{error} || $error);
+            $field->errors->add($field->{error} || $error);
             
             return 0;
 
@@ -1175,7 +1175,7 @@ sub configuration_validator_max_symbols {
             my $error = "$handle can't contain more than "
                 ."$directive $characters";
             
-            $field->errors->add_error($field->{error} || $error);
+            $field->errors->add($field->{error} || $error);
 
             return 0;
 
@@ -1204,7 +1204,7 @@ sub configuration_validator_min_alpha {
             my $error = "$handle must contain at-least "
                 ."$directive alphabetic $characters";
             
-            $field->errors->add_error($field->{error} || $error);
+            $field->errors->add($field->{error} || $error);
 
             return 0;
 
@@ -1233,7 +1233,7 @@ sub configuration_validator_min_digits {
             my $error = "$handle must contain at-least "
                 ."$directive $characters";
             
-            $field->errors->add_error($field->{error} || $error);
+            $field->errors->add($field->{error} || $error);
 
             return 0;
 
@@ -1260,7 +1260,7 @@ sub configuration_validator_min_length {
             my $error = "$handle must contain at-least "
                 ."$directive $characters";
             
-            $field->errors->add_error($field->{error} || $error);
+            $field->errors->add($field->{error} || $error);
 
             return 0;
 
@@ -1284,7 +1284,7 @@ sub configuration_validator_min_sum {
             my $error = "$handle can't be less than "
             ."$directive";
             
-            $field->errors->add_error($field->{error} || $error);
+            $field->errors->add($field->{error} || $error);
 
             return 0;
 
@@ -1313,7 +1313,7 @@ sub configuration_validator_min_symbols {
             my $error = "$handle must contain at-least "
                 ."$directive $characters";
             
-            $field->errors->add_error($field->{error} || $error);
+            $field->errors->add($field->{error} || $error);
 
             return 0;
 
@@ -1341,7 +1341,7 @@ sub configuration_validator_options {
             
             my $error = "$handle must be " . join " or ", @options;
             
-            $field->errors->add_error($field->{error} || $error);
+            $field->errors->add($field->{error} || $error);
 
             return 0;
 
@@ -1377,9 +1377,9 @@ sub error_fields {
         
         my $field = $self->fields->{$name};
         
-        if ($field->{errors}->has_errors) {
+        if ($field->{errors}->count) {
             
-            $failed->{$name} = $field->{errors}->error_list;
+            $failed->{$name} = $field->{errors}->list;
         
         }
         
@@ -1396,11 +1396,11 @@ sub errors_to_string {
     
     my $errors = Validation::Class::Errors->new([]); # handle combined errors
     
-    $errors->add_errors($self->{errors}->all_errors);
+    $errors->add($self->{errors}->all);
     
     $self->fields->each(sub{
         
-        $errors->add_errors($_[1]->{errors}->all_errors);
+        $errors->add($_[1]->{errors}->all);
         
     });
     
@@ -1433,7 +1433,7 @@ sub configuration_validator_pattern {
             my $error = "$handle does not match the "
                 ."pattern $directive";
             
-            $field->errors->add_error($field->{error} || $error);
+            $field->errors->add($field->{error} || $error);
 
             return 0;
 
@@ -1487,11 +1487,11 @@ sub get_errors {
     
     if (!@criteria) {
         
-        $errors->add_errors($self->{errors}->all_errors);
+        $errors->add($self->{errors}->all);
         
         $self->fields->each(sub{
             
-            $errors->add_errors($_[1]->{errors}->all_errors);
+            $errors->add($_[1]->{errors}->all);
             
         });
         
@@ -1501,11 +1501,11 @@ sub get_errors {
         
         my $query = $criteria[0];
         
-        $errors->add_errors($self->{errors}->find_errors($query));
+        $errors->add($self->{errors}->find($query));
         
         $self->fields->each(sub{
             
-            $errors->add_errors($_[1]->{errors}->find_errors($query));
+            $errors->add($_[1]->{errors}->find($query));
             
         });
         
@@ -1515,13 +1515,13 @@ sub get_errors {
         
         for (@criteria) {
         
-            $errors->add_errors($self->fields->{$_}->{errors}->all_errors);
+            $errors->add($self->fields->{$_}->{errors}->all);
         
         }
         
     }
     
-    return ($errors->all_errors);
+    return ($errors->all);
 
 }
 
@@ -1906,7 +1906,7 @@ sub pitch_error {
         
         if ($self->report_unknown) {
         
-            $self->errors->add_error($error_message);
+            $self->errors->add($error_message);
         
         }
         
@@ -1991,11 +1991,11 @@ sub reset_errors {
 
     my $self = shift;
     
-    $self->errors->clear_errors;
+    $self->errors->clear;
     
     foreach my $field ($self->fields->values) {
         
-        $field->{errors}->clear_errors;
+        $field->{errors}->clear;
         
     }
     
@@ -2029,7 +2029,7 @@ sub set_errors {
 
     my ($self, @errors) = @_;
     
-    $self->errors->add_errors(@errors)  if @errors;
+    $self->errors->add(@errors)  if @errors;
     
     return @errors;
 
@@ -2333,7 +2333,7 @@ sub validate {
                             
                             if (defined $field->{error}) {
     
-                                $field->{errors}->add_error($field->{error});
+                                $field->{errors}->add($field->{error});
     
                             }
     
@@ -2345,7 +2345,7 @@ sub validate {
                                     "could not be validated"
                                 ;
                                 
-                                $field->{errors}->add_error($error_msg);
+                                $field->{errors}->add($error_msg);
                                 
                             }
                             
@@ -2400,7 +2400,7 @@ sub validate {
                             
                             if ( defined $field->{error} ) {
     
-                                $field->{errors}->add_error($field->{error});
+                                $field->{errors}->add($field->{error});
     
                             }
     
@@ -2412,7 +2412,7 @@ sub validate {
                                     "could not be validated"
                                 ;
                                 
-                                $field->{errors}->add_error($error_msg);
+                                $field->{errors}->add($error_msg);
                                 
                             }
                             
@@ -2472,7 +2472,7 @@ sub validate {
                             
                             if (defined $field->{error}) {
     
-                                $field->{errors}->add_error($field->{error});
+                                $field->{errors}->add($field->{error});
     
                             }
     
@@ -2484,7 +2484,7 @@ sub validate {
                                     "could not be validated"
                                 ;
                                 
-                                $field->{errors}->add_error($error_msg);
+                                $field->{errors}->add($error_msg);
                                 
                             }
                             
@@ -2511,7 +2511,7 @@ sub validate {
     
                 if ($self->report_unknown) {
     
-                    $self->errors->add_error($error);
+                    $self->errors->add($error);
     
                 }
     
@@ -2589,7 +2589,7 @@ Validation::Class::Prototype - Data Validation Engine for Validation::Class Clas
 
 =head1 VERSION
 
-version 7.00_01
+version 7.00_02
 
 =head1 SYNOPSIS
 
